---
title: <span class="badge object-type-enum"></span> HttpRequestMethod
---
# <span class="badge object-type-enum"></span> HttpRequestMethod

## Definition

```python
class HttpRequestMethod(enum.StrEnum):
    GET = "GET"
    POST = "POST"
    PUT = "PUT"
```
